
API
===


Base
----

.. autoclass:: flask_occam.plugin.Occam
   :members:

.. autoclass:: flask_occam.plugin.DataLoader
   :members:
      

Databse Mixins
--------------

.. autoclass:: flask_occam.mixins.ModelMixin
   :members:


Handlers
--------

.. autoclass:: flask_occam.handlers.ActionHandler
   :members:


.. autoclass:: flask_occam.handlers.QueryHandler
   :members:


Converters
----------

.. autoclass:: flask_occam.converters.ModelConverter
   :members:


Decorators
----------

.. autoclass:: flask_occam.decorators.log
   :members:

.. autofunction:: flask_occam.decorators.paginate

.. autofunction:: flask_occam.decorators.transactional

.. autoclass:: flask_occam.decorators.validate
    :members:
